export declare const MANIFEST_VERSION = 7;
export declare const MANIFEST_FILE_NAME = "manifest.json";
export declare const DIFF_BOUNDARY = "~";
export declare const PC_HIDDEN_DIR = ".paperclip";
export declare const DIFF_DIR: string;
export declare const DATA_DIR: string;
export declare const SCREENSHOTS_DIR: string;
export declare type WindowSize = {
    width: number;
    height: number;
};
export declare type FrameScreenshotDiff = {
    id: string;
    changeCount: number;
    screnshotId: string;
    otherScreenshotId: string;
};
export declare type FrameScreenshot = {
    id: string;
    browser: string;
    size: WindowSize;
    diffIds: string[];
};
export declare type FrameSnapshot = {
    id: string;
    hash: string;
    title: string;
    sourceFilePath: string;
    screenshotIds: string[];
};
export declare type ProjectSnapshot = {
    version: string;
    frameIds: string[];
};
export declare type Manifest = {
    version: number;
    diffs: FrameScreenshotDiff[];
    screenshots: FrameScreenshot[];
    frameSnapshots: FrameSnapshot[];
    projectSnapshots: ProjectSnapshot[];
    commitAliases: Record<string, string>;
};
export declare type ExpandedFrameScreenshot = {
    diffs: FrameScreenshotDiff[];
} & FrameScreenshot;
export declare type ExpandedFrameSnapshot = {
    screenshots: ExpandedFrameScreenshot[];
} & FrameSnapshot;
export declare type ExpandedProjectSnapshot = {
    frames: ExpandedFrameSnapshot[];
} & ProjectSnapshot;
export declare const screenshotEquals: (a: FrameScreenshot, b: FrameScreenshot) => boolean;
export declare const sizeEquals: (a: WindowSize, b: WindowSize) => boolean;
export declare const getProjectSnapshot: (version: string, manifest: Manifest) => ProjectSnapshot;
export declare const getProjectFrames: (project: ProjectSnapshot, manifest: Manifest) => FrameSnapshot[];
export declare const getFrameScreenshots: (frame: FrameSnapshot, manifest: Manifest) => FrameScreenshot[];
export declare const getScreenshotDiffs: (screenshot: FrameScreenshot, manifest: Manifest) => FrameScreenshotDiff[];
export declare const getProjectScreenshots: (version: string, manifest: Manifest) => FrameScreenshot[];
export declare const getDiffFrame: (diff: FrameScreenshotDiff, manifest: Manifest) => FrameSnapshot;
export declare const getProjectDiffs: (version: string, manifest: Manifest) => FrameScreenshotDiff[];
export declare const getChanges: (version1: string, version2: string, manifest: Manifest) => FrameScreenshotDiff[];
export declare const addDiffToManifest: (screenshotId: string, screenshotDiff: FrameScreenshotDiff, manifest: Manifest) => Manifest;
export declare const addFrameSnapshots: (projectSnapshot: ProjectSnapshot, frames: FrameSnapshot[], screenshots: FrameScreenshot[], gitDir: string, version: string, tagName: string, manifest: Manifest) => Promise<Manifest>;
export declare const getScreenshotPath: (gitDir: string, id: string) => string;
